@@ -5,15 +5,15 @@ def format_company_id_en(value, route_key, key="haohaoxuexi"):
     if route_key in ["core.patent", "core.patent_lite"]:
         for data in value.get("tags", {}).get("proposer_type", []):
             if data.get("code"):
-                data["code"] = AES.encrypt(key, data["code"])
+                data["code"] = AES.encrypt(key=key, text=data["code"])
     elif route_key in ["core.research_institution"]:
         for data in value.get("tags", {}).get("support_unit", []):
             if data.get("id"):
-                data["id"] = AES.encrypt(key, data["id"])
+                data["id"] = AES.encrypt(key=key, text=data["id"])
     elif route_key in ["core.investment"]:
         for data in value.get("tags", {}).get("invest_company", []):
             if data.get("company_id"):
-                data["company_id"] = AES.encrypt(key, data["company_id"])
+                data["company_id"] = AES.encrypt(key=key, text=data["company_id"])
 
 
 def format_es_param_result(r, param_list, is_need_decrypt, is_need_es_score, route_key, key="haohaoxuexi"):
@@ -44,7 +44,7 @@ def format_es_param_result(r, param_list, is_need_decrypt, is_need_es_score, rou
     else:
         result_dict = r["_source"]
     if is_need_decrypt:
-        r["_id"] = AES.encrypt(key)
+        r["_id"] = AES.encrypt(key=key, text=r["_id"])
     result_dict["_id"] = r["_id"]
     if is_need_es_score:
         result_dict["_score"] = r["_score"]
@@ -143,7 +143,7 @@ def es_condition_by_terms(bool_must_list, column, param_list, is_need_decrypt=Fa
             for index, _id in enumerate(param_list):
                 # noinspection PyBroadException
                 try:
-                    _id = AES.decrypt(key, _id)
+                    _id = AES.decrypt(key=key, text=_id)
                     param_list[index] = int(_id)
                 except Exception:
                     pass
